@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,19 @@
 #include "messageview.h"
 #include "compose.h"
 
+typedef void (*SetPositionFunc)(void *obj, gint pos);
+typedef gboolean (*SearchStringFunc)(void *obj,
+	const gchar *str, gboolean case_sens);
+
+typedef struct {
+	SetPositionFunc set_position;
+	SearchStringFunc search_string;
+	SearchStringFunc search_string_backward;
+} SearchInterface;
+
 void message_search	(MessageView	*messageview);
 void message_search_compose	(Compose	*compose);
+void message_search_other	(SearchInterface	*source, void *obj);
+void message_search_close	(void *obj);
 
 #endif /* __MESSAGE_SEARCH_H__ */
